@@ -2,6 +2,7 @@
 # Copyright 2008-2018 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 import os
+import sys
 import logging
 from gi.repository import GObject
 from gi.repository import Gtk
@@ -15,6 +16,7 @@ from zim.signals import DelayedCallback
 
 from zim.notebook import Path, Page, LINK_DIR_BACKWARD
 from zim.notebook.index import IndexNotFoundError
+from zim.notebook.operations import ongoing_operation
 from zim.history import History, HistoryPath
 
 from zim.actions import action, toggle_action, radio_action, radio_option, get_gtk_actiongroup, \
@@ -246,7 +248,7 @@ class MainWindow(Window):
 
 		# specify statusbar elements right-to-left
 		self.statusbar_insert_label = statusbar_element('INS', 60)
-		self.statusbar_style_label = statusbar_element('<style>', 100)
+		self.statusbar_style_label = statusbar_element('<style>', 110)
 
 		# and build the widget for backlinks
 		self.statusbar_backlinks_button = \
@@ -286,6 +288,10 @@ class MainWindow(Window):
 		self.uimanager.insert_action_group(group, 0)
 
 		group = get_gtk_actiongroup(self)
+		# don't use mnemonics on macOS to allow alt-<letter> shortcuts
+		global MENU_ACTIONS
+		if sys.platform == "darwin":
+			MENU_ACTIONS = tuple((t[0], t[1], t[2].replace('_', '')) for t in MENU_ACTIONS)
 		group.add_actions(MENU_ACTIONS)
 		self.uimanager.insert_action_group(group, 0)
 
@@ -341,25 +347,31 @@ class MainWindow(Window):
 		closing if there are no other toplevel windows.
 		'''
 		if self.hideonclose: # XXX
-			self.save_uistate()
-			self.hide()
-			self.emit('close')
+			self._do_close()
 		else:
 			self.destroy()
 
+	def _do_close(self):
+		self.save_uistate()
+		self.hide()
+		self.emit('close')
+
 	def destroy(self):
 		self.pageview.save_changes()
 		if self.page.modified:
 			return # Do not quit if page not saved
 		self.pageview.page.set_ui_object(None) # XXX
 
-		self.save_uistate()
+		self._do_close()
 
-		self.hide() # look more responsive
-		self.notebook.index.stop_background_check()
 		while Gtk.events_pending():
 			Gtk.main_iteration_do(False)
 
+		self.notebook.index.stop_background_check()
+		op = ongoing_operation(self.notebook)
+		if op:
+			op.wait()
+
 		Window.destroy(self) # gtk destroy & will also emit destroy signal
 
 	def do_update_statusbar(self, *a):
@@ -398,7 +410,7 @@ class MainWindow(Window):
 			# Hidden param, disabled because it causes problems with
 			# several international layouts (space mistaken for alt-space,
 			# see bug lp:620315)
-			group.connect_group( # <Alt><Space>
+			group.connect( # <Alt><Space>
 				space, Gdk.ModifierType.MOD1_MASK, Gtk.AccelFlags.VISIBLE,
 				self.toggle_sidepane_focus)
 
@@ -711,8 +723,8 @@ class MainWindow(Window):
 			text = 'INS'
 		self.statusbar_insert_label.set_text(text)
 
-	def on_textview_textstyle_changed(self, view, style):
-		label = style.title() if style else 'None'
+	def on_textview_textstyle_changed(self, view, styles):
+		label = ", ".join([s.title() for s in styles if s]) if styles else 'None'
 		self.statusbar_style_label.set_text(label)
 
 	def on_link_enter(self, view, link):
